@@ -1,6 +1,7 @@
-from typing import Any, Dict, Sequence
+from typing import Any, Dict, Sequence, TypeVar
 
 
 Argv = Sequence[str]
 DictStrAny = Dict[str, Any]
 DictStrStr = Dict[str, str]
+T = TypeVar("T")
